@@ -8,7 +8,7 @@ from typing import Union, List, Dict, Any, Optional, cast, Tuple
 import math 
 import numpy as np
 
-from benchay.codes.astrape_pkg.astrape.utilities.utils import rearrange_dims
+from astrape.utilities.utils import rearrange_dims
 
 applicable_val_metric_list = APPLICABLE_VAL_METRIC_LIST
 applicable_optimizer_type_list = APPLICABLE_OPTIMIZER_TYPE_LIST
