@@ -1050,7 +1050,7 @@ class UNet(ConvNet):
             'n_layers' : 3,
             'features_start' : 64,
             'bilinear' : False,
-            'dataformats' : "NHWC"
+            'dataformats' : "NCHW"
         }
          
         # set default for model-specific hyperparameters
@@ -1174,7 +1174,7 @@ class PixelCNN(ConvNet):
         default_parameter_dict = {
             'n_blocks' : 5,
             'hidden_channels' : 10,
-            'dataformats' : "NHWC"
+            'dataformats' : "NCHW"
         }
         
         for argument, default in default_parameter_dict.items():
