@@ -307,17 +307,17 @@ def divide_set(X, y, column, value):
 def rearrange_dims(dims, in_format, dataformats="NCHW"):
     def find_mapping(in_format, dataformats):
         mappings = list(permutations([0,1,2]))
-        c_to_i = {"N" : 0, "C" : 1, "H" : 2, "W" : 3}
-        in_format_array = np.array([])
-        dataformat_array = np.array([])
+        c_to_i = {"C" : 0, "H" : 1, "W" : 2}
+        in_format_array = []
+        dataformat_array = []
         for c_in, c_out in zip(in_format, dataformats):
-            in_format_array = np.concatenate([in_format_array, np.array([c_to_i[c_in]])]).astype(int)
-            dataformat_array = np.concatenate([dataformat_array, np.array([c_to_i[c_out]])]).astype(int)
+            if c_in != "N" and c_out != "N":
+                in_format_array.append(int(c_to_i[c_in]))
+                dataformat_array.append(int(c_to_i[c_out]))
         for mapping in mappings:
-            mapped = np.transpose(in_format_array, mapping)
+            mapped = list(in_format_array[mapping[0]], in_format_array[mapping[1]], in_format_array[mapping[2]])
             if mapped == dataformat_array:
-                break
-        return mapping
+                return mapping
 
     if isinstance(dims, int):
             raise ValueError(f"Wrong dimension {dims} for an input.")
@@ -326,9 +326,8 @@ def rearrange_dims(dims, in_format, dataformats="NCHW"):
         width = dims[1]
         dims = (1, height, width)
     elif len(dims) == 3:
-        temp = np.array(dims)
         mapping = find_mapping(in_format, dataformats)
-        dims = tuple(np.transpose(temp, mapping))
+        dims = tuple(dims[mapping[0]], dims[mapping[1]], dims[mapping[2]])
         
     else:
         raise ValueError(f"Wrong dimension {dims} for an input.")
